#ifndef MYLOG_H__
#define MYLOG_H__

void my_log_close();
int mylog_init();

#ifdef LOG_PRODUCTION
#define my_zlog_debug(...) ((void)0)
#define my_zlog_info(...)  ((void)0)
#else
void my_zlog_debug(const char *format, ...) ;
void my_zlog_info(const char *format, ...) ;
#endif

void my_zlog_notice(const char *format, ...) ;
void my_zlog_warn(const char *format, ...) ;
void my_zlog_error(const char *format, ...) ;
void my_zlog_fatal(const char *format, ...) ;

#endif